@@ -1,12 +1,12 @@
 package Params::Validate;
-# git description: v1.16-2-g457b527
 
-$Params::Validate::VERSION = '1.17';
 use 5.008001;
 
 use strict;
 use warnings;
 
+our $VERSION = '1.19';
+
 use Exporter;
 use Module::Implementation;
 use Params::Validate::Constants;
@@ -75,7 +75,7 @@ Params::Validate - Validate method/function parameters
 
 =head1 VERSION
 
-version 1.17
+version 1.19
 
 =head1 SYNOPSIS
 
@@ -454,11 +454,6 @@ exception message generated by C<Params::Validate>. If the callback dies with
 a reference (blessed or not), then this will be rethrown as-is by
 C<Params::Validate>.
 
-Any existing C<$SIG{__DIE__}> value will be temporarily removed while
-callbacks are called in order to prevent the die handler from tampering with
-the error thrown by the callback. However, under Perl 5.8.x this cannot be
-implemented in the XS version of C<Params::Validate>.
-
 =head2 Untainting
 
 If you want values untainted, set the "untaint" key in a spec hashref
