@@ -1,8 +1,10 @@
 package Params::Validate::PP;
-$Params::Validate::PP::VERSION = '1.17';
+
 use strict;
 use warnings;
 
+our $VERSION = '1.19';
+
 use Params::Validate::Constants;
 use Scalar::Util 1.10 ();
 
@@ -43,7 +45,7 @@ sub validate_pos (\@@) {
 
         # if the spec is bigger that's where we can start adding
         # defaults
-        for ( my $x = $#p + 1 ; $x <= $#specs ; $x++ ) {
+        for ( my $x = $#p + 1; $x <= $#specs; $x++ ) {
             $p[$x] = $specs[$x]->{default}
                 if ref $specs[$x] && exists $specs[$x]->{default};
         }
@@ -346,7 +348,7 @@ OUTER:
     if (@missing) {
         my $called = _get_called();
 
-        my $missing = join ', ', map { "'$_'" } @missing;
+        my $missing = join ', ', map {"'$_'"} @missing;
         $options->{on_fail}->( "Mandatory parameter"
                 . ( @missing > 1 ? 's' : '' )
                 . " $missing missing in call to $called\n" );
@@ -500,7 +502,7 @@ sub _validate_one_param {
                 }
                 ) {
                 my $is = ref $value ? ref $value : 'plain scalar';
-                my $article1 = $_  =~ /^[aeiou]/i ? 'an' : 'a';
+                my $article1 = $_ =~ /^[aeiou]/i  ? 'an' : 'a';
                 my $article2 = $is =~ /^[aeiou]/i ? 'an' : 'a';
 
                 my $called = _get_called(1);
@@ -549,7 +551,7 @@ sub _validate_one_param {
             my $ok;
             my $e = do {
                 local $@ = q{};
-                local $SIG{__DIE__} = undef;
+                local $SIG{__DIE__};
                 $ok = eval { $spec->{callbacks}{$_}->( $value, $params ) };
                 $@;
             };
